package com.zhyc.module.feed.service;

import java.util.List;
import com.zhyc.module.feed.domain.SgMaterial;

/**
 * 原料Service接口
 * 
 * @author HashMap
 * @date 2026-01-16
 */
public interface ISgMaterialService 
{
    /**
     * 查询原料
     * 
     * @param materialId 原料主键
     * @return 原料
     */
    public SgMaterial selectSgMaterialByMaterialId(String materialId);

    /**
     * 查询原料列表
     * 
     * @param sgMaterial 原料
     * @return 原料集合
     */
    public List<SgMaterial> selectSgMaterialList(SgMaterial sgMaterial);

    /**
     * 新增原料
     * 
     * @param sgMaterial 原料
     * @return 结果
     */
    public int insertSgMaterial(SgMaterial sgMaterial);

    /**
     * 修改原料
     * 
     * @param sgMaterial 原料
     * @return 结果
     */
    public int updateSgMaterial(SgMaterial sgMaterial);

    /**
     * 批量删除原料
     * 
     * @param materialIds 需要删除的原料主键集合
     * @return 结果
     */
    public int deleteSgMaterialByMaterialIds(String[] materialIds);

    /**
     * 删除原料信息
     * 
     * @param materialId 原料主键
     * @return 结果
     */
    public int deleteSgMaterialByMaterialId(String materialId);
}
